function move=CTFT(My_hist, Opp_hist)
% strategy Contrite Tit for Tat in Iterated Prisoners Dilemma
% takes My and Opponent's history, evaluates my and opponent's standing 
% and returns my move
% The move will be cooperate unless I am in good standing and my opponent
% is in bad standing

% auxiliary variables to keep track of standing
Good = 1; % good standing
Bad = 2;  % bad standing

    function MS = standing (MyMove, MyStanding, OppMove, OppStanding)
        % this function returns my standing as it changed after one round
        % of PD game. It takes my and opponent's last moves and my and
        % opponent's last standing.
        % I am in good standing only if in the last round 
        % (i)   I cooperated and my opponent was in good standing; or
        % (ii)  I cooperated and I was in bad standing; or
        % (iii) I defected and I was in good standing, while my opponent
        %       was in bad standing
        if ((MyMove == Cooperate) && (OppStanding == Good)) || ...
           ((MyMove == Cooperate) && (MyStanding == Bad)) || ...
           ((MyMove == Defect)    && (OppStanding == Bad)) 
           MS = Good;
        else
            MS = Bad;
        end;
    end % function standing

currentRound = length(My_hist) + 1; % current round of the game
if currentRound == 1 % first move
    move = Cooperate;
else % not a first round 
%% iteratively get standing in all rounds from the histories
    My_Standing_Hist(1) = Good; % all start with good standing
    Opp_Standing_Hist(1) = Good;
    for r = 2:currentRound
      My_Standing_Hist(r) = standing(My_hist(r-1), My_Standing_Hist(r-1), ...
                                     Opp_hist(r-1), Opp_Standing_Hist(r-1));
      Opp_Standing_Hist(r) = standing(Opp_hist(r-1), Opp_Standing_Hist(r-1), ...
                                     My_hist(r-1), My_Standing_Hist(r-1));                                 
    end; % for r 
%% get my move
    if (My_Standing_Hist(currentRound) == Good) && ...
            (Opp_Standing_Hist(currentRound) == Bad)
        move = Defect;
    else
        move = Cooperate;
    end;
end; % if currentRound == 1

end % function CTFT