function sperm_competition
% this script produces figures 16.6 for sperm competition games
% the user has to specify the parameters R, D, r, e
% the function solves a system of equations and plots the ESS 

%% User defined input
R=3;        % total energy available for reproduction
D=1;        % the cost per unit of sperm produced
r=0.2;      % discount factor for a second mating
e=0.001;    % probability of female to remain unfertilized

%% Calculations
function S=findESS(q) 
    % takes q, the proportion of females that mate with two males
    % returns ESS as a solution of a given system of Eqs
    % S(1) will be s_01, S(2) will be s_2
    function F=SystemOfEqs(x) % defines equations to solve
        % the system depends on q which is the input of findESS
        F=[(1-q)*e/(x(1)+e)^2+q *(r* x(2) +e)/(x(1)+r*x(2)+e)^2  - x(3)*D;
            r*(x(1)+e)/(x(1)+r*x(2)+e)^2  - x(3)*D;
            x(1)*(1-q)/(x(1)+e)+ q*x(1)/(x(1)+r*x(2)+e)+ ...
                    q*r*x(2)/(x(2)+r*x(2)+e) - x(3)*R];
    end
    x0 = [0.1 0.5 0.5];  % Make a starting guess at the solution
    options = optimset('Display','off');  % Turn off display
    [S,dummy1,dummy2] = fsolve(@SystemOfEqs,x0,options); 
               % solves the system F=0 and outputs the solution
end

qq=linspace(0.0,1, 11); % sampling of q (probability of double mating)
s1=zeros(1,length(qq)); % init of s1, $s_{0,1}$ in the text
s2=s1;                  % init of s2, $s_2$ in the text
for index=1:length(qq)  % for each value of q
    solution = findESS(qq(index)); % get the ESS solution
    s1(index) = solution(1);   % get s1 as first coordinate
    s2(index) = solution(2);   % get s2 as second coordinate 
end;

%% plotting 
plot(qq,s1, '-', qq,s2, '--', qq, (s1+qq.*s2)./(1+qq), ':');
legend('s*_0_,_1', 's*_2', 'average')
axis([0 1 0 1]);
xlabel('Probability of double mating \it q');
ylabel('Sperm allocation');

end

