function IFD
% implementation of an Ideal Free distribution 
% payoffs of patches defined inside of  this  function

    % list of players entering the tournament
    patches = struct(...
        'B', {10, 5, 2.5}, ... % suitability IN DECREASING ORDER
        'R',  {@R1, @R2, @R3});   % payoff to individuals on patch i
   
    n = length(patches); % how many patches are there
    IFD=zeros(n,1); % init value of the outcome
    
%% definitions of functions specifying payoffs on patches
    N=45; % number of individuals to be then used in the formulae
    
    function payoff=R1(dens)
        payoff=patches(1).B-dens*N/10;
    end;
    
    function payoff=R2(dens)
        payoff=patches(2).B-dens*N/10;
    end;
    
    function payoff=R3(dens)
        payoff=patches(3).B-dens*N/10;
    end;
    
%% determine how many patches are occupied in IFD
    function E=IFDeqs(x) % system of eqs that IFD has to solve
        for i=1:length(x) % the first is a constant 0, but does not matter
            E(i) = patches(1).R(x(1))-patches(i).R(x(i));
        end
    end;

    n_o = 1; % start with only one patch occupied
    x=1; % 'guess' the solution that all will be on that patch
    % repeat the following loop while the guess is not correct
    % i.e. while the payoff on the first patch is less than on the next
    % unoccupied patch
    while ((n_o<n) & (patches(1).R(x(1))<patches(n_o+1).B)) 
        n_o=n_o+1;
        x0=zeros(n_o,1);
        x0(1) = 1;  % Make a starting guess at the solution
        options = optimset('Display','off');  % Turn off display
        [x,Fval,exitflag] = fsolve(@IFDeqs,x0,options);
   end;
    
%% display the outcomes
IFD(1:n_o)=x

end

