function repdyn
% shows replicator dynamics for the RSP game with given by 
% the payoff matrix A

% define a payoff matrix
A=[ 0, 1,-1;  % payoffs to Rock
   -2, 0, 2;  % payoffs to Scissors
    2,-1, 0]; % payoffs to Paper

Init_Y= [1-1/5 1/10 1/10]; % set the initial conditions

% set the coordinates for the triangle
R = [0,0]; % coordinates of Rock, i.e. strategy  (1,0,0) 
S = [1,0]; % coordinates of Scissors, i.e. strategy (0,1,0)
P = [1/2,sqrt(3)/2]; % coordinates of Paper, i.e. strategy (0,0,1)
% R will be the lower left vertex, S the lower right vertex and 
% P will be the top vertex

% define the replicator dynamics
    function dy = dynamics(t,y)
        dy = y.*((A*y) - y'*A*y);
    end
% solve the dynamics
options = odeset('RelTol',1e-4,'AbsTol',[1e-4 1e-4 1e-5]);
[dummy,Y] = ode45(@dynamics,[0 100],Init_Y,options);

figure(1);
hold on
axis off % turn off the axes so that they are not visible
% draw the triangle
line([R(1) S(1) P(1) R(1)], [R(2) S(2) P(2) R(2)]); 

% plot the dynamics
coord(1,:) = Y(:,1)*R(1) + Y(:,2)*S(1)+ Y(:,3)*P(1); % x 
coord(2,:) = Y(:,1)*R(2) + Y(:,2)*S(2)+ Y(:,3)*P(2); % y 
plot(coord(1,:),coord(2,:));

end
